@@ -49,11 +49,14 @@ class Reply(object):
                     ENHANCEDSTATUSCODES_ string.
     :param command: The command that is waiting for the reply, typically for
                     logging or debugging.
+    :param address: Information about the remote host that gave the reply, see
+                    :py:mod:`socket` for details.
 
     """
 
-    def __init__(self, code=None, message=None, command=None):
+    def __init__(self, code=None, message=None, command=None, address=None):
         self.command = command
+        self.address = address
 
         #: Holds the reply code, which can only be set to a string containing
         #: three digits.
@@ -73,6 +76,8 @@ class Reply(object):
         self.newline_first = False
 
     def __eq__(self, other):
+        if not hasattr(other, 'code') or not hasattr(other, 'message'):
+            return NotImplemented
         return self.code == other.code and self.message == other.message
 
     def __repr__(self):
@@ -95,7 +100,18 @@ class Reply(object):
         """
         return '{0} {1}'.format(self.code, self.message)
 
-    def __nonzero__(self):
+    def __bytes__(self):
+        """Converts the reply into a single bytestring.
+
+        :returns: The code, ENHANCEDSTATUSCODES_ string, and the message,
+                  separated by spaces.
+        :rtype: :py:obj:`bytes`
+
+        """
+        return b' '.join((self.code.encode('ascii'),
+                          self.message.encode('utf-8')))
+
+    def __bool__(self):
         """Defines the truth-testing operation for |Reply| objects. This will
         evaluate ``True`` if the object value set to its ``code`` attribute
         other than ``None``. This is useful for checking replies that may be
@@ -106,6 +122,9 @@ class Reply(object):
         """
         return self.code is not None
 
+    # Python 2 compat.
+    __nonzero__ = __bool__
+
     def copy(self, reply):
         """Direct-copies the given reply code and message into the current
         object. This is generally useful for sending pre-defined responses.
@@ -116,6 +135,7 @@ class Reply(object):
         self._code = reply._code
         self._message = reply._message
         self._esc = reply._esc
+        return self
 
     def recv(self, io):
         """Populates the object with the code and message received from the
@@ -125,6 +145,7 @@ class Reply(object):
 
         """
         self.code, self.message = io.recv_reply()
+        self.address = io.address
 
     def send(self, io, flush=False):
         """Sends the reply to the session.
@@ -134,7 +155,7 @@ class Reply(object):
 
         """
         if self.newline_first:
-            io.buffered_send('\r\n')
+            io.buffered_send(b'\r\n')
         io.send_reply(self)
         if flush:
             io.flush_send()
@@ -146,8 +167,7 @@ class Reply(object):
         :rtype: True or False
 
         """
-        code_class = self.code[0]
-        return code_class == '4' or code_class == '5'
+        return self.code[0] in ('4', '5')
 
     @property
     def code(self):
@@ -187,13 +207,14 @@ class Reply(object):
 
     @property
     def enhanced_status_code(self):
-        if self._code and self._code[0] in ('2', '4', '5'):
+        code_0 = self._code and self._code[0]
+        if code_0 in ('2', '4', '5'):
             if self._esc:
-                return '.'.join((self._code[0], self._esc[1], self._esc[2]))
+                return '.'.join((code_0, self._esc[1], self._esc[2]))
             elif self._esc is False:
                 return None
             else:
-                return '.'.join((self._code[0], '0', '0'))
+                return '.'.join((code_0, '0', '0'))
 
     @enhanced_status_code.setter
     def enhanced_status_code(self, value):
@@ -234,7 +255,8 @@ timed_out = Reply('421', '4.4.2 Connection timed out')
 timed_out.newline_first = True
 
 #: Reply sent when an authentication attempt resulted in invalid credentials.
-invalid_credentials = Reply('535', '5.7.8 Authentication credentials invalid')
+invalid_credentials = Reply(
+    '535', '5.7.8 Authentication credentials invalid')
 
 
 # vim:et:fdm=marker:sts=4:sw=4:ts=4
