@@ -21,6 +21,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         super(TestSmtpRelayClient, self).setUp()
         self.sock = self.mox.CreateMock(socket)
         self.sock.fileno = lambda: -1
+        self.sock.getpeername = lambda: ('test', 0)
         self.queue = self.mox.CreateMock(BlockingDeque)
         self.tls_args = {'test': 'test'}
 
@@ -51,96 +52,79 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
             client._banner()
 
     def test_ehlo(self):
-        self.sock.sendall(b'EHLO test\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 TEST\r\n')
-        self.sock.sendall(b'EHLO test\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'420 Goodbye\r\n')
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='there')
         client._connect()
         client._ehlo()
         with self.assertRaises(TransientRelayError):
             client._ehlo()
 
     def test_starttls(self):
-        sock = self.mox.CreateMockAnything()
-        sock.fileno = lambda: -1
-        def socket_creator(address):
-            return sock
-        sock.sendall(b'STARTTLS\r\n')
-        sock.recv(IsA(int)).AndReturn(b'220 Go ahead\r\n')
-        sock.tls_wrapper(sock, self.tls_args).AndReturn(sock)
-        sock.sendall(b'STARTTLS\r\n')
-        sock.recv(IsA(int)).AndReturn(b'420 Stop\r\n')
+        tls_wrapper = self.mox.CreateMockAnything()
+        self.sock.sendall(b'STARTTLS\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'220 Go ahead\r\n')
+        tls_wrapper(self.sock, self.tls_args).AndReturn(self.sock)
+        self.sock.sendall(b'STARTTLS\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'420 Stop\r\n')
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', self.queue, socket_creator=socket_creator, tls=self.tls_args, tls_wrapper=sock.tls_wrapper, tls_required=True)
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, tls=self.tls_args, tls_wrapper=tls_wrapper, tls_required=True)
         client._connect()
         client._starttls()
         with self.assertRaises(TransientRelayError):
             client._starttls()
 
     def test_handshake_tls_immediately(self):
-        sock = self.mox.CreateMockAnything()
-        sock.fileno = lambda: -1
-        def socket_creator(address):
-            return sock
-        sock.tls_wrapper(sock, self.tls_args).AndReturn(sock)
-        sock.recv(IsA(int)).AndReturn(b'220 Welcome\r\n')
-        sock.sendall(b'EHLO test\r\n')
-        sock.recv(IsA(int)).AndReturn(b'250 Hello\r\n')
+        tls_wrapper = self.mox.CreateMockAnything()
+        tls_wrapper(self.sock, self.tls_args).AndReturn(self.sock)
+        self.sock.recv(IsA(int)).AndReturn(b'220 Welcome\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'250 Hello\r\n')
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', self.queue, socket_creator=socket_creator, tls=self.tls_args, tls_wrapper=sock.tls_wrapper, tls_immediately=True, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, tls=self.tls_args, tls_wrapper=tls_wrapper, tls_immediately=True, ehlo_as='there')
         client._connect()
         client._handshake()
 
     def test_handshake_starttls(self):
-        sock = self.mox.CreateMockAnything()
-        sock.fileno = lambda: -1
-        def socket_creator(address):
-            return sock
-        sock.recv(IsA(int)).AndReturn(b'220 Welcome\r\n')
-        sock.sendall(b'EHLO test\r\n')
-        sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 STARTTLS\r\n')
-        sock.sendall(b'STARTTLS\r\n')
-        sock.recv(IsA(int)).AndReturn(b'220 Go ahead\r\n')
-        sock.tls_wrapper(sock, self.tls_args).AndReturn(sock)
-        sock.sendall(b'EHLO test\r\n')
-        sock.recv(IsA(int)).AndReturn(b'250 Hello\r\n')
+        tls_wrapper = self.mox.CreateMockAnything()
+        self.sock.recv(IsA(int)).AndReturn(b'220 Welcome\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 STARTTLS\r\n')
+        self.sock.sendall(b'STARTTLS\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'220 Go ahead\r\n')
+        tls_wrapper(self.sock, self.tls_args).AndReturn(self.sock)
+        self.sock.sendall(b'EHLO there\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'250 Hello\r\n')
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', self.queue, socket_creator=socket_creator, tls=self.tls_args, tls_wrapper=sock.tls_wrapper, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, tls=self.tls_args, tls_wrapper=tls_wrapper, ehlo_as='there')
         client._connect()
         client._handshake()
 
     def test_handshake_authenticate(self):
-        sock = self.mox.CreateMockAnything()
-        sock.fileno = lambda: -1
-        def socket_creator(address):
-            return sock
-        sock.recv(IsA(int)).AndReturn(b'220 Welcome\r\n')
-        sock.sendall(b'EHLO test\r\n')
-        sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 AUTH PLAIN\r\n')
-        sock.sendall(b'AUTH PLAIN AHRlc3RAZXhhbXBsZS5jb20AcGFzc3dk\r\n')
-        sock.recv(IsA(int)).AndReturn(b'235 Ok\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'220 Welcome\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 AUTH PLAIN\r\n')
+        self.sock.sendall(b'AUTH PLAIN AHRlc3RAZXhhbXBsZS5jb20AcGFzc3dk\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'235 Ok\r\n')
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', self.queue, socket_creator=socket_creator, credentials=('test@example.com', 'passwd'), ehlo_as=b'test')
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, credentials=('test@example.com', 'passwd'), ehlo_as='there')
         client._connect()
         client._handshake()
 
     def test_handshake_authenticate_callable(self):
-        sock = self.mox.CreateMockAnything()
-        sock.fileno = lambda: -1
-        def socket_creator(address):
-            return sock
-        sock.recv(IsA(int)).AndReturn(b'220 Welcome\r\n')
-        sock.sendall(b'EHLO test\r\n')
-        sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 AUTH PLAIN\r\n')
-        sock.sendall(b'AUTH PLAIN AHRlc3RAZXhhbXBsZS5jb20AcGFzc3dk\r\n')
-        sock.recv(IsA(int)).AndReturn(b'235 Ok\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'220 Welcome\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 AUTH PLAIN\r\n')
+        self.sock.sendall(b'AUTH PLAIN AHRlc3RAZXhhbXBsZS5jb20AcGFzc3dk\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'235 Ok\r\n')
         self.mox.ReplayAll()
         def yield_creds():
             yield 'test@example.com'
             yield 'passwd'
-        client = SmtpRelayClient('addr', self.queue, socket_creator=socket_creator, credentials=yield_creds, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, credentials=yield_creds, ehlo_as='there')
         client._connect()
         client._handshake()
 
@@ -153,17 +137,13 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         client._rset()
 
     def test_handshake_authenticate_badcreds(self):
-        sock = self.mox.CreateMockAnything()
-        sock.fileno = lambda: -1
-        def socket_creator(address):
-            return sock
-        sock.recv(IsA(int)).AndReturn(b'220 Welcome\r\n')
-        sock.sendall(b'EHLO test\r\n')
-        sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 AUTH PLAIN\r\n')
-        sock.sendall(b'AUTH PLAIN AHRlc3RAZXhhbXBsZS5jb20AcGFzc3dk\r\n')
-        sock.recv(IsA(int)).AndReturn(b'535 Nope!\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'220 Welcome\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 AUTH PLAIN\r\n')
+        self.sock.sendall(b'AUTH PLAIN AHRlc3RAZXhhbXBsZS5jb20AcGFzc3dk\r\n')
+        self.sock.recv(IsA(int)).AndReturn(b'535 Nope!\r\n')
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', self.queue, socket_creator=socket_creator, credentials=('test@example.com', 'passwd'), ehlo_as=b'test')
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, credentials=('test@example.com', 'passwd'), ehlo_as='there')
         client._connect()
         with self.assertRaises(PermanentRelayError):
             client._handshake()
@@ -206,7 +186,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         result = AsyncResult()
         env = Envelope('sender@example.com', ['rcpt@example.com'])
         env.parse(b'From: sender@example.com\r\n\r\ntest test \x81\r\n')
-        self.sock.sendall(b'EHLO test\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 8BITMIME\r\n')
         self.sock.sendall(b'MAIL FROM:<sender@example.com>\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n')
@@ -217,7 +197,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.sendall(b'From: sender@example.com\r\n\r\ntest test \x81\r\n.\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n')
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='there')
         client._connect()
         client._ehlo()
         client._deliver(result, env)
@@ -227,14 +207,14 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         result = AsyncResult()
         env = Envelope('sender@example.com', ['rcpt@example.com'])
         env.parse(b'From: sender@example.com\r\n\r\ntest test\r\n')
-        self.sock.sendall(b'EHLO test\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 PIPELINING\r\n')
         self.sock.sendall(b'MAIL FROM:<sender@example.com>\r\nRCPT TO:<rcpt@example.com>\r\nDATA\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'550 Not ok\r\n250 Ok\r\n354 Go ahead\r\n')
         self.sock.sendall(b'.\r\nRSET\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'550 Yikes\r\n250 Ok\r\n')
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='there')
         client._connect()
         client._ehlo()
         client._deliver(result, env)
@@ -245,7 +225,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         result = AsyncResult()
         env = Envelope('sender@example.com', ['rcpt@example.com'])
         env.parse(b'From: sender@example.com\r\n\r\ntest test\r\n')
-        self.sock.sendall(b'EHLO test\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 PIPELINING\r\n')
         self.sock.sendall(b'MAIL FROM:<sender@example.com>\r\nRCPT TO:<rcpt@example.com>\r\nDATA\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n250 Ok\r\n354 Go ahead\r\n')
@@ -254,7 +234,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.sendall(b'RSET\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n')
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='there')
         client._connect()
         client._ehlo()
         client._deliver(result, env)
@@ -265,14 +245,14 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         result = AsyncResult()
         env = Envelope('sender@example.com', ['rcpt@example.com'])
         env.parse(b'From: sender@example.com\r\n\r\ntest test\r\n')
-        self.sock.sendall(b'EHLO test\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 PIPELINING\r\n')
         self.sock.sendall(b'MAIL FROM:<sender@example.com>\r\nRCPT TO:<rcpt@example.com>\r\nDATA\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n550 Not ok\r\n354 Go ahead\r\n')
         self.sock.sendall(b'.\r\nRSET\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'550 Yikes\r\n250 Ok\r\n')
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='there')
         client._connect()
         client._ehlo()
         client._deliver(result, env)
@@ -283,14 +263,14 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         result = AsyncResult()
         env = Envelope('sender@example.com', ['rcpt@example.com'])
         env.parse(b'From: sender@example.com\r\n\r\ntest test\r\n')
-        self.sock.sendall(b'EHLO test\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 PIPELINING\r\n')
         self.sock.sendall(b'MAIL FROM:<sender@example.com>\r\nRCPT TO:<rcpt@example.com>\r\nDATA\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n250 Ok\r\n450 No!\r\n')
         self.sock.sendall(b'RSET\r\n')
         self.sock.recv(IsA(int)).AndRaise(ConnectionLost)
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='there')
         client._connect()
         client._ehlo()
         with self.assertRaises(ConnectionLost):
@@ -302,7 +282,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         result = AsyncResult()
         env = Envelope('sender@example.com', ['rcpt@example.com'])
         env.parse(b'From: sender@example.com\r\n\r\ntest test \x81\r\n')
-        self.sock.sendall(b'EHLO test\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 PIPELINING\r\n')
         self.sock.sendall(b'MAIL FROM:<sender@example.com>\r\nRCPT TO:<rcpt@example.com>\r\nDATA\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n250 Ok\r\n354 Go ahead\r\n')
@@ -312,7 +292,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
             self.sock.sendall(b'From: sender@example.com\r\nContent-Transfer-Encoding: base64\r\n\r\ndGVzdCB0ZXN0IIENCg==\r\n.\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n')
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test', binary_encoder=encode_base64)
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='there', binary_encoder=encode_base64)
         client._connect()
         client._ehlo()
         client._deliver(result, env)
@@ -322,12 +302,12 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         result = AsyncResult()
         env = Envelope('bsender@example.com', ['rcpt@example.com'])
         env.parse(b'From: sender@example.com\r\n\r\ntest test \x81\r\n')
-        self.sock.sendall(b'EHLO test\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 PIPELINING\r\n')
         self.sock.sendall(b'RSET\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n')
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='there')
         client._connect()
         client._ehlo()
         client._deliver(result, env)
@@ -339,7 +319,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'221 Goodbye\r\n')
         self.sock.close()
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='there')
         client._connect()
         client._disconnect()
 
@@ -348,7 +328,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndRaise(socket_error(None, None))
         self.sock.close()
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', self.queue, socket_creator=self._socket_creator, ehlo_as='there')
         client._connect()
         client._disconnect()
 
@@ -359,7 +339,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         queue = BlockingDeque()
         queue.append((result, env))
         self.sock.recv(IsA(int)).AndReturn(b'220 Welcome\r\n')
-        self.sock.sendall(b'EHLO test\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 PIPELINING\r\n')
         self.sock.sendall(b'MAIL FROM:<sender@example.com>\r\nRCPT TO:<rcpt@example.com>\r\nDATA\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n250 Ok\r\n354 Go ahead\r\n')
@@ -369,7 +349,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'221 Goodbye\r\n')
         self.sock.close()
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', queue, socket_creator=self._socket_creator, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', queue, socket_creator=self._socket_creator, ehlo_as='there')
         client._run()
         self.assertEqual({'rcpt@example.com': Reply('250', 'Ok')}, result.get_nowait())
 
@@ -384,7 +364,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         queue.append((result1, env1))
         queue.append((result2, env2))
         self.sock.recv(IsA(int)).AndReturn(b'220 Welcome\r\n')
-        self.sock.sendall(b'EHLO test\r\n')
+        self.sock.sendall(b'EHLO there\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250-Hello\r\n250 PIPELINING\r\n')
         self.sock.sendall(b'MAIL FROM:<sender1@example.com>\r\nRCPT TO:<rcpt1@example.com>\r\nDATA\r\n')
         self.sock.recv(IsA(int)).AndReturn(b'250 Ok\r\n250 Ok\r\n354 Go ahead\r\n')
@@ -398,7 +378,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'221 Goodbye\r\n')
         self.sock.close()
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', queue, socket_creator=self._socket_creator, ehlo_as=b'test', idle_timeout=0.0)
+        client = SmtpRelayClient('addr', queue, socket_creator=self._socket_creator, ehlo_as='there', idle_timeout=0.0)
         client._run()
         self.assertEqual({'rcpt1@example.com': Reply('250', 'Ok')}, result1.get_nowait())
         self.assertEqual({'rcpt2@example.com': Reply('250', 'Ok')}, result2.get_nowait())
@@ -414,7 +394,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'221 Goodbye\r\n')
         self.sock.close()
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', queue, socket_creator=self._socket_creator, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', queue, socket_creator=self._socket_creator, ehlo_as='there')
         with self.assertRaises(ValueError):
             client._run()
         with self.assertRaises(ValueError):
@@ -431,7 +411,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'221 Goodbye\r\n')
         self.sock.close()
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', queue, socket_creator=self._socket_creator, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', queue, socket_creator=self._socket_creator, ehlo_as='there')
         client._run()
         with self.assertRaises(TransientRelayError):
             result.get_nowait()
@@ -447,7 +427,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'221 Goodbye\r\n')
         self.sock.close()
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', queue, socket_creator=self._socket_creator, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', queue, socket_creator=self._socket_creator, ehlo_as='there')
         client._run()
         with self.assertRaises(TransientRelayError):
             result.get_nowait()
@@ -463,7 +443,7 @@ class TestSmtpRelayClient(unittest.TestCase, MoxTestBase):
         self.sock.recv(IsA(int)).AndReturn(b'221 Goodbye\r\n')
         self.sock.close()
         self.mox.ReplayAll()
-        client = SmtpRelayClient('addr', queue, socket_creator=self._socket_creator, ehlo_as=b'test')
+        client = SmtpRelayClient('addr', queue, socket_creator=self._socket_creator, ehlo_as='there')
         client._run()
         with self.assertRaises(PermanentRelayError):
             result.get_nowait()
